#!/usr/bin/env python3
##
## -----------------------------------------------------------------
##    This file is part of WAPT Software Deployment
##    Copyright (C) 2012 - 2020  Tranquil IT https://www.tranquil.it
##    All Rights Reserved.
##
##    WAPT helps systems administrators to efficiently deploy
##    setup, update and configure applications.
## ------------------------------------------------------------------
##
import os
import sys

from waptserver.config import __version__

from flask import request, send_from_directory, Blueprint
from werkzeug.utils import secure_filename

import hashlib
import json
import ujson
import random
import re
import requests
import shutil
import stat
import subprocess
import time
import traceback
import uuid

import waptserver.config

from waptserver.utils import *
from waptserver.model import *
from waptserver.config import get_http_proxies

from waptserver.common import make_response, make_response_from_exception
from waptserver.decorators import requires_auth, requires_enterprise

from waptserver.wsus_tasks import download_wsusscan, download_windows_update_task, download_missing_cabs, huey
from waptserver.wsus_common import simplematch, products_id, update_classifications_id, get_product_id
from waptserver.wsus_common import check_sha1_filename, wuredist_extract_and_fetch, cabextract, check_cab
from waptserver.wsus import wsus

from waptserver.server_socketio import socketio, proxy_host_request

wsus_socketio = Blueprint('wsus_socketio', __name__)

DEFAULT_CONFIG_FILE = os.path.join(wapt_root_dir, 'conf', 'waptserver.ini')
config_file = DEFAULT_CONFIG_FILE

conf = waptserver.config.load_config(config_file)

try:
    # i18n
    from flask_babel import Babel
    from flask_babel import gettext
except ImportError:
    gettext = (lambda s: s)
    Babel = None

_ = gettext


@wsus_socketio.route('/api/v3/trigger_waptwua_scan', methods=['HEAD', 'GET', 'POST'])
@requires_enterprise
@requires_auth(['admin','view'])
def trigger_waptwua_scan():
    """Proxy the wapt update action to the client"""
    return proxy_host_request(request, 'trigger_waptwua_scan')


@wsus_socketio.route('/api/v3/trigger_waptwua_download', methods=['HEAD', 'GET', 'POST'])
@requires_enterprise
@requires_auth(['admin','view'])
def trigger_waptwua_download():
    """Proxy the wapt download action to the client"""
    return proxy_host_request(request, 'trigger_waptwua_download')


@wsus_socketio.route('/api/v3/trigger_waptwua_install', methods=['HEAD', 'GET', 'POST'])
@requires_enterprise
@requires_auth(['admin','view'])
def trigger_waptwua_install():
    """Proxy the wapt scan action to the client"""
    return proxy_host_request(request, 'trigger_waptwua_install')
